<div class="modal fade" id="{{ id }}" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-dialog-top" role="document">
        <div class="modal-content">
            <div class="modal-header">
                {% if close_btn %}
                    <button type="button" class="close" data-dismiss="modal" aria-label=""><span aria-hidden="true">&times;</span></button>
                {% endif %}
                <h4 class="modal-title">{{ title }}</h4>
            </div>
            <div class="modal-body">
                {{ body }}
            </div>
        </div>
    </div>
</div>
