{% load i18n %}
<div class="text-center">
    <div style="padding-bottom: 20px;">
        <h2 class='text-danger'>
            <span class='glyphicon glyphicon-alert'></span> {% trans "Permission Denied" %}
        </h2>
    </div>
    <p>{% trans "You do not have the necessary permission to complete this operation" %}</p>
</div>
